@@ -1,7 +1,7 @@
 """
 The tool to update the input repositories of the Ultimate-Hosts-Blacklist project.
 
-The main entry of the tool.
+The main entrypoint.
 
 License:
 ::
@@ -9,9 +9,9 @@ License:
 
     MIT License
 
-    Copyright (c) 2019 Ultimate-Hosts-Blacklist
-    Copyright (c) 2019 Nissar Chababy
-    Copyright (c) 2019 Mitchell Krog
+    Copyright (c) 2019, 2020  Ultimate-Hosts-Blacklist
+    Copyright (c) 2019, 2020  Nissar Chababy
+    Copyright (c) 2019, 2020  Mitchell Krog
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to deal
@@ -31,14 +31,19 @@ License:
     OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
     SOFTWARE.
 """
+
 import argparse
 import logging
 
 from colorama import Fore, Style
 from colorama import init as initiate_coloration
-from ultimate_hosts_blacklist.input_repo_updater.core import Core
+from PyFunceble import VERSION as PyFuncebleVersion
 
-VERSION = "1.17.1"
+from .authorization import Authorization
+from .pre_loader import PreLoader
+from .tester import Tester
+
+VERSION = "2.0.0"
 
 
 def _command_line():
@@ -50,7 +55,8 @@ def _command_line():
         initiate_coloration(autoreset=True)
 
         parser = argparse.ArgumentParser(
-            description="The tool to update the input repositories of the Ultimate-Hosts-Blacklist project.",  # pylint: disable=line-too-long
+            description="The tool to update the input repositories of "
+            "the Ultimate-Hosts-Blacklist project.",
             epilog="Crafted with %s by %s"
             % (
                 Fore.RED + "♥" + Fore.RESET,
@@ -74,14 +80,6 @@ def _command_line():
             default=False,
         )
 
-        parser.add_argument(
-            "-p",
-            "--processes",
-            help="Set the maximal number of process to use.",
-            type=int,
-            default=25,
-        )
-
         parser.add_argument(
             "-v",
             "--version",
@@ -97,8 +95,19 @@ def _command_line():
         else:
             logging_level = logging.INFO
 
-        Core(
-            logging_level=logging_level,
-            multiprocessing=arguments.multiprocess,
-            processes=arguments.processes,
-        ).process()
+        logging.basicConfig(
+            format="[%(asctime)s::%(levelname)s] %(message)s", level=logging_level
+        )
+
+        logging.info("Launcher version: %s", VERSION)
+        logging.info("PyFunceble version: %s", PyFuncebleVersion)
+
+        authorization = Authorization()
+
+        if authorization.get_authorization():
+            PreLoader(authorization)
+            Tester(arguments.multiprocess)
+
+        # Core(
+        #     logging_level=logging_level, multiprocessing=arguments.multiprocess
+        # ).process()
